Periodic sweeper for stale dynamic metric series.
Advances the global eviction cycle and evicts series that have been inactive for longer than the configured threshold. This bounds memory usage from dynamic labels regardless of which exporters are active.
The actual eviction logic is provided by the caller via a closure, making this work with any metrics struct that has dynamic series.
Structs
- Sweep
Config - Configuration for the stale-series sweeper.
Functions
- run
- Run the stale-series sweep loop.